str_values

Function str_values 

pub fn str_values(col: &dyn Array) -> StrColumn<'_>
The same, for the one caller that reaches the column by name because the table it holds may be missing it — see frame::resource_names.