stage

Function stage 

fn stage(tmp: &Path, sealed: &Sealed) -> Result<()>
Write one sealed block’s files into an already-created staging directory.

Split out of publish only so that the failure of any step in it has one place to be cleaned up from.