expand

Function expand 

pub fn expand(
    root: &Path,
    f: &Frame,
    ops: &[Expand],
    open: &[Arc<Open>],
) -> Result<(Frame, Stats)>
Apply a walk to a frame, in order.

In order and not as a set, because they do not commute: Around after Traces widens the measured extent of the traces, Around before it is overwritten by the measurement.