pub fn resource_key(attrs: &[KeyValue]) -> u64Expand description
The stable 64-bit identity of the entity described by attrs, or
NO_IDENTITY if nothing identifying is present.
pub fn resource_key(attrs: &[KeyValue]) -> u64The stable 64-bit identity of the entity described by attrs, or
NO_IDENTITY if nothing identifying is present.