struct DpHead {
id: UInt32Builder,
metric_id: UInt32Builder,
start: TimestampNanosecondBuilder,
time: TimestampNanosecondBuilder,
flags: UInt32Builder,
}Expand description
The five columns every point table starts with. Grouped so that the four tables cannot drift apart, which would make a temporal filter four functions.
Fields
id: UInt32Buildermetric_id: UInt32Builderstart: TimestampNanosecondBuildertime: TimestampNanosecondBuilderflags: UInt32BuilderImplementations