upper_attrs

Function upper_attrs 

fn upper_attrs(
    metrics: &RecordBatch,
    row: usize,
    metric_attrs: &Option<Attrs>,
    resource_attrs: &Option<Attrs>,
    scope_attrs: &Option<Attrs>,
) -> Vec<(String, String)>
Attributes from the metric, resource and scope levels, sorted and deduped with the most specific level winning.