fn mix(x: u64) -> u64Expand description
splitmix64’s finalizer, as in crate::bloom: the domain constant above
only separates the two spaces if every input bit reaches every output bit.
fn mix(x: u64) -> u64splitmix64’s finalizer, as in crate::bloom: the domain constant above
only separates the two spaces if every input bit reaches every output bit.